*** do-file for Ongena and Popov

use "C:\Users\popoval\Desktop\Paper with Steven\JMCB files\MS14-239_Main.dta", clear

global finance_vars share_banks share_trade_credit constrained_discouraged constrained_rejected
global firm_vars female small_firm big_firm originally_private exporter competition subsidized audited 
global loan_vars loan_time loan_collateral_no collateral_perc loan_for_curr loan_rate_nom
global country_vars private_credit_gdp bank_concentration info_sharing log_gdp_per_cap gdp_gr creditors_rights enforcing_payment inflation entry_time

**********************************************************
***									                   ***
***     Table 1. Access to finance summary stats       ***
***									                   ***
**********************************************************

bysort country: gen number=_N

tabstat number $finance_vars, s(mean) by(country)

**********************************************************
***									                   ***
***       Table 2. Loan variables summary stats        ***
***									                   ***
**********************************************************

tabstat $loan_vars, s(mean) by(country)

**********************************************************
***									                   ***
***    Appendix Table 1. Firm controls summary stats   ***
***									                   ***
**********************************************************

tabstat $firm_vars, s(mean) by(country)

**********************************************************
***									                   ***
***  Appendix Table 2. Country controls summary stats  ***
***									                   ***
**********************************************************

tabstat female_family $country_vars, s(mean) by(country)

* log close 
* view sumtables.smcl

/* assign values to missing country-level variables */

bysort country: egen gggi2006_av=max(gggi2006)
replace gggi2006=gggi2006_av if gggi2006==.

bysort country: egen wvs_av=max(wvs)
replace wvs=wvs_av if wvs==.

bysort country: egen foreign_banks_av=mean(foreign_banks)
replace foreign_banks=foreign_banks_av if foreign_banks==.

bysort country: egen private_credit_gdp_av=mean(private_credit_gdp)
replace private_credit_gdp=private_credit_gdp_av if private_credit_gdp==.

bysort country: egen bank_concentration_av=mean(bank_concentration)
replace bank_concentration=bank_concentration_av if bank_concentration==.

bysort country: egen info_sharing_av=mean(info_sharing)
replace info_sharing=info_sharing_av if info_sharing==.

bysort country: egen gdp_per_cap_av=mean(gdp_per_cap)
replace gdp_per_cap=gdp_per_cap_av if gdp_per_cap==.

bysort country: egen gdp_gr_av=mean(gdp_gr)
replace gdp_gr=gdp_gr_av if gdp_gr==.

bysort country: egen creditors_rights_av=mean(creditors_rights)
replace creditors_rights=creditors_rights_av if creditors_rights==.

bysort country: egen enforcing_payment_av=mean(enforcing_payment)
replace enforcing_payment=enforcing_payment_av if enforcing_payment==.

bysort country: egen inflation_av=mean(inflation)
replace inflation=inflation_av if inflation==.

**********************************************************
***									                   ***
***  Table 4. Gender, culture, and access to finance   ***
***									                   ***
**********************************************************

gen log_gdp_per_cap_av=log(gdp_per_cap_av)
replace enforcing_payment_av=enforcing_payment_av/100
replace gdp_gr_av=gdp_gr_av*100

global country_vars_av foreign_banks_av private_credit_gdp_av bank_concentration_av info_sharing_av gdp_gr_av creditors_rights_av enforcing_payment_av inflation_av entry_time

/* generate interaction of female dummy with cultural attitudes */

gen fem_family=female*female_family /* it is much better for everyone if man is the achiever outside the home and the woman takes care of the home and family */

gen fem_gggi=female*gggi2006
gen fem_wvs=female*wvs

gen female_family_dummy=0
replace female_family_dummy=1 if female_family>0.03
gen fem_family_dummy=female*female_family_dummy

* Panel A 
xi: reg share_banks fem_family_dummy $firm_vars i.industry*i.country, cluster(country)
predict y1
* Panel B
bootstrap, reps(1000): reg share_banks fem_family_dummy $firm_vars c_1-c_17 i_1-i_8 c_i_1_1-c_i_17_8 if y1!=., robust

* Panel A
xi: reg share_trade_credit fem_family_dummy $firm_vars i.industry*i.country, cluster(country)
predict y2
* Panel B
bootstrap, reps(1000): reg share_trade_credit fem_family_dummy $firm_vars c_1-c_17 i_1-i_8 c_i_1_1-c_i_17_8 if y2!=., robust

* Panel A
xi: probit constrained_discouraged fem_family_dummy $firm_vars i.industry*i.country, cluster(country)
predict y3
* Panel B
bootstrap, reps(1000): probit constrained_discouraged fem_family_dummy $firm_vars c_1-c_17 i_1-i_8 c_i_1_1-c_i_17_8 if y3!=., robust

* Panel A
xi: probit constrained_rejected fem_family_dummy $firm_vars i.industry*i.country, cluster(country)
predict y4
* Panel B
bootstrap, reps(1000): probit constrained_rejected fem_family_dummy $firm_vars c_1-c_17 i_1-i_8 c_i_1_1-c_i_17_8 if y4!=., robust

** back of the envelope calculation
* 2.5 mln SMEs in Spain.
* 19% female-owned -> 475,000
* 39% of those have positive demand for bank loans -> 185,250
* 20% discouraged -> 37050
* 6% more

**********************************************************
***									                   ***
***      Table 5. Gender, culture, and loan terms      ***
***									                   ***
**********************************************************

replace enforcing_payment=enforcing_payment/100
replace gdp_gr=gdp_gr*100
replace private_credit_gdp=private_credit_gdp*100

replace log_gdp_per_cap=log(gdp_per_cap)

global country_vars foreign_banks private_credit_gdp bank_concentration info_sharing gdp_per_cap gdp_gr creditors_rights pop_gr inflation entry_time

xi: reg log_loan_time fem_family_dummy $firm_vars $country_vars i.industry*i.country i.year, cluster(country) 
xi: probit loan_collateral_no fem_family_dummy  $firm_vars $country_vars i.industry i.country i.year, cluster(country) 
xi: reg log_collateral_perc fem_family_dummy  $firm_vars $country_vars i.industry*i.country i.year, cluster(country) 
xi: probit loan_for_curr fem_family_dummy  $firm_vars $country_vars i.industry i.country i.year, cluster(country) 
xi: reg loan_rate_nom fem_family_dummy  $firm_vars $country_vars i.industry*i.country i.year, cluster(country) 

**********************************************************
***									                   ***
***               Table 6. Robust controls             ***
***									                   ***
**********************************************************

global country_vars foreign_banks private_credit_gdp bank_concentration info_sharing gdp_per_cap gdp_gr pop_gr creditors_rights inflation entry_time

foreach x of global country_vars {
gen female_`x'=`x'*female
}

global female_country_vars female_foreign_banks female_private_credit_gdp female_bank_concentration female_info_sharing female_gdp_per_cap female_gdp_gr female_pop_gr female_creditors_rights female_inflation female_entry_time

xi: reg share_banks fem_family_dummy $female_country_vars $firm_vars i.industry*i.country, cluster(country)
xi: reg share_trade_credit fem_family_dummy $female_country_vars $firm_vars i.industry*i.country, cluster(country)
xi: probit constrained_discouraged fem_family_dummy $female_country_vars $firm_vars i.industry*i.country, cluster(country)
xi: probit constrained_rejected fem_family_dummy $female_country_vars $firm_vars i.industry*i.country, cluster(country)

**********************************************************
***									                   ***
***             Table 7. Robust gender bias           ***
***									                   ***
**********************************************************

gen female_family_dummy_f=0
replace female_family_dummy_f=1 if female_family>0.0055
gen fem_family_dummy_f=female*female_family_dummy_f

** Panel A. Continuous bias

xi: reg share_banks fem_family $firm_vars i.industry*i.country, cluster(country)
xi: reg share_trade_credit fem_family $firm_vars i.industry*i.country, cluster(country)
xi: probit constrained_discouraged fem_family $firm_vars i.industry*i.country, cluster(country)
xi: probit constrained_rejected fem_family $firm_vars i.industry*i.country, cluster(country)

** Panel B. Excluding medium-bias countries

xi: reg share_banks fem_family_dummy $firm_vars i.industry*i.country if country!="Germany" & country!="Greece" & country!="Portugal", cluster(country)
xi: reg share_trade_credit fem_family_dummy $firm_vars i.industry*i.country if country!="Germany" & country!="Greece" & country!="Portugal", cluster(country)
xi: probit constrained_discouraged fem_family_dummy $firm_vars i.industry*i.country if country!="Germany" & country!="Greece" & country!="Portugal", cluster(country)
xi: probit constrained_rejected fem_family_dummy $firm_vars i.industry*i.country if country!="Germany" & country!="Greece" & country!="Portugal", cluster(country)

** Panel C. Female bias
xi: reg share_banks fem_family_dummy_f $firm_vars i.industry*i.country, cluster(country)
xi: reg share_trade_credit fem_family_dummy_f $firm_vars i.industry*i.country, cluster(country)
xi: probit constrained_discouraged fem_family_dummy_f $firm_vars i.industry*i.country, cluster(country)
xi: probit constrained_rejected fem_family_dummy_f $firm_vars i.industry*i.country, cluster(country)

**********************************************************
***									                   ***
***    Table 9. Gender, culture, and discouragement   ***
***									                   ***
**********************************************************

xi: probit constrained_discouraged_2 fem_family_dummy $firm_vars i.industry*i.country, cluster(country)
xi: probit constrained_discouraged_3 fem_family_dummy $firm_vars i.industry*i.country, cluster(country)
xi: probit constrained_discouraged_4 fem_family_dummy $firm_vars i.industry*i.country, cluster(country)
xi: probit constrained_discouraged_6 fem_family_dummy $firm_vars i.industry i.country, cluster(country)

************************************************************
***									                     ***
*** Table 13A. Sales growth, culture, gender, and credit ***
***									                     ***
************************************************************

gen female_constrained_rejected=female*constrained_rejected
gen female_constrained_discouraged=female*constrained_discouraged

gen criterion_a=.
replace criterion_a=0 if female==0 & constrained==0
replace criterion_a=1 if female==1 & constrained==1

gen criterion_a_female_family_dummy=criterion_a*female_family_dummy

gen log_sales_gr=log(sales_gr)

xi: reg sales_gr $firm_vars i.industry*i.country, cluster(country) 
xi: reg sales_gr fem_family_dummy $firm_vars i.industry*i.country, cluster(country) 
xi: reg sales_gr criterion_a small_firm big_firm originally_private exporter competition subsidized audited  i.industry*i.country, cluster(country) 
xi: reg sales_gr criterion_a_female_family_dummy criterion_a small_firm big_firm originally_private exporter competition subsidized audited  i.industry*i.country, cluster(country) 

***************************************************************************
***									                                    ***
*** Table 13B. Comparing observables across gender and access to credit ***
***									                                    ***
***************************************************************************

gen applied=.
replace applied=0 if constrained_discouraged==1
replace applied=1 if constrained_rejected==1 | has_loan==1

global firm_vars small_firm big_firm originally_private exporter competition subsidized audited 

gen female_applied=applied*female

xi: probit small_firm female_applied female applied i.industry*i.country, cluster(country) 
xi: probit big_firm female_applied female applied i.industry*i.country, cluster(country) 
xi: probit originally_private female_applied female applied i.industry*i.country, cluster(country) 
xi: probit exporter female_applied female applied i.industry*i.country, cluster(country) 
xi: probit competition female_applied female applied i.industry*i.country, cluster(country) 
xi: probit subsidized female_applied female applied i.industry*i.country, cluster(country) 
xi: probit audited female_applied female applied i.industry*i.country, cluster(country) 

***********************************************************
***									                    ***
***       Appendix Table 3: Country controls 1 by 1     ***
***									                    ***
***********************************************************

global female_country_vars female_foreign_banks female_private_credit_gdp female_bank_concentration female_info_sharing female_gdp_per_cap female_gdp_gr female_pop_gr female_creditors_rights female_inflation female_entry_time

xi: probit constrained_discouraged fem_family_dummy female_foreign_banks $firm_vars i.industry*i.country, cluster(country)
xi: probit constrained_discouraged fem_family_dummy female_private_credit_gdp $firm_vars i.industry*i.country, cluster(country)
xi: probit constrained_discouraged fem_family_dummy female_bank_concentration $firm_vars i.industry*i.country, cluster(country)
xi: probit constrained_discouraged fem_family_dummy female_info_sharing $firm_vars i.industry*i.country, cluster(country)
xi: probit constrained_discouraged fem_family_dummy female_gdp_per_cap $firm_vars i.industry*i.country, cluster(country)
xi: probit constrained_discouraged fem_family_dummy female_gdp_gr $firm_vars i.industry*i.country, cluster(country)
xi: probit constrained_discouraged fem_family_dummy female_pop_gr $firm_vars i.industry*i.country, cluster(country)
xi: probit constrained_discouraged fem_family_dummy female_creditors_rights $firm_vars i.industry*i.country, cluster(country)
xi: probit constrained_discouraged fem_family_dummy female_inflation $firm_vars i.industry*i.country, cluster(country)
xi: probit constrained_discouraged fem_family_dummy female_entry_time $firm_vars i.industry*i.country, cluster(country)

**********************************************************
***									                   ***
***                      THE END     			       ***
***									                   ***
**********************************************************
